// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KCMUTILS_VERSION_H
#define KCMUTILS_VERSION_H

#define KCMUTILS_VERSION_STRING "5.98.0"
#define KCMUTILS_VERSION_MAJOR 5
#define KCMUTILS_VERSION_MINOR 98
#define KCMUTILS_VERSION_PATCH 0
#define KCMUTILS_VERSION ((5<<16)|(98<<8)|(0))

#endif
